"""Provides the Credit class."""

from pathlib import Path
from typing import Optional

from attr import attrs


@attrs(auto_attribs=True)
class Credit:
    """A credit in a game.

    :ivar ~earwax.Credit.name: The name of the person or company who is being
        credited.

        This value will be shown in a menu generated by
        :metH:`earwax.Menu.from_credits`.

    :ivar ~earwax.Credit.url: The URL to open when this credit is selected.

    :ivar ~earwax.Credit.sound: An optional sound to play while this credit is
        shown.

    :ivar ~earwax.Credit.loop: Whether ot not to loop
        :attr:`~earwax.Credit.sound`.
    """

    name: str
    url: str
    sound: Optional[Path] = None
    loop: bool = True

    @classmethod
    def earwax_credit(cls) -> 'Credit':
        """Get an earwax credit."""
        return cls(
            'Chris Norman (the Earwax game engine)',
            'https://www.github.com/chrisnorman7/earwax'
        )
